<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       catchplugins.com
 * @since      1.0.0
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/admin/partials
 */

?>

<?php

$username                                 = '';
$catch_instagram_feed_gallery_widget_page = admin_url( 'admin.php?page=social-gallery-and-widget' );
$catch_instagram_feed_gallery_widget_page_redirect = $catch_instagram_feed_gallery_widget_page . '&response_type=token&state=' . admin_url( 'admin.php?page=social-gallery-and-widget' );
$options = catch_instagram_feed_gallery_widget_pro_get_options();

if ( '' !== $options['access_token'] ) {
	$time = $options['expires_in'];
	$now  = time();

	// Calculate remaining time for instagram's token expiration.
	$remaining = $now - $time;

	// Refresh access token when 7 days expiration time is remaining.
	if ( $remaining > -604800 ) {

		$re_data = Catch_Instagram_Feed_Gallery_Widget_Pro_Admin::refresh_access_token();

	}
}

if ( ( isset( $_GET['business_access_token'] ) && ! empty( $_GET['business_access_token'] ) ) ) {

	$business_token = isset( $_GET['business_access_token'] ) ? $_GET['business_access_token'] : $options['business_access_token'];
	$expires_in     = isset( $_GET['expires_in'] ) ? $_GET['expires_in'] : $options['expires_in'];

	// <!-- Select Facebook Pages -->
	//if ( '' === $options['instagram_business_account_id'] ) {
	$url = 'https://graph.facebook.com/me/accounts?fields=picture{url},app_id,name,instagram_business_account,username&access_token=' . $business_token;
	$alt = Catch_Instagram_Feed_Gallery_Widget_Pro_Admin::get_remote_data_in_json( $url );
	$alt = json_decode( $alt, true );

	?>

		<div class="modal-container">
			<div class="modal-page">

			<?php

			if ( isset( $alt['data'] ) && 0 < count( $alt['data'] ) ) {

				?>

				<h3><?php esc_html_e( 'Instagram Business profiles for this account' ); ?></h3>

					<?php

					foreach ( $alt['data'] as $page ) {

						$instagram_business_account_id = '0';

						if ( isset( $page['instagram_business_account']['id'] ) ) {

							?>

							<input type="hidden" name="catch-instagram-business-nonce" id="catch-instagram-business-nonce" value="<?php echo esc_attr( wp_create_nonce( 'catch-instagram-business-nonce' ) ); ?>" />
							<p class="info">

								<?php esc_html_e( 'Note: In order to display a Hashtag feed you first need to select a Business profile below.', 'catch-instagram-feed-gallery-widget-pro' ); ?>

							</p>

							<?php $instagram_business_account_id = $page['instagram_business_account']['id']; ?>

							<div class="fb-page-info" data-page-name="<?php echo esc_attr( $page['name'] ); ?>" data-page-id="<?php echo esc_attr( $page['id'] ); ?>" data-business-id="<?php echo esc_attr( $instagram_business_account_id ); ?>" data-token="<?php echo esc_attr( $_GET['business_access_token'] ); ?>" data-expires-in="<?php echo esc_attr( $expires_in ); ?>">
								<span style="float: left;" class="facebook-page">
									<img src="<?php echo esc_url( $page['picture']['data']['url'] ); ?>" />
								</span>
								<span style="margin-top: 5px; margin-bottom: 5px; display: inline-block;"><?php echo esc_html( $page['name'] ); ?></span>
								<br />
								<span>@<?php echo esc_html( $page['username'] ); ?>(<?php echo esc_html( $instagram_business_account_id ); ?>)</span>
							</div>

							<?php

						}
					}

					?>

					<div class="clearfix"></div>
					<br />

					<?php

			} else {

				?>

					<span id="sbi-bus-account-error">
						<p style="margin-top: 5px;"><b style="font-size: 16px">Couldn't find Business Profile</b><br>
							Uh oh. It looks like this Facebook account is not currently connected to an Instagram Business profile.
							Please check that you are logged into the <a href="<?php esc_html( 'https://www.facebook.com/' ); ?>" target="_blank">Facebook
								account</a> in this browser which is associated with your Instagram Business Profile.</p>
						<p><b style="font-size: 16px">Why do I need a Business Profile?</b><br>
							A Business Profile is only required if you are displaying a Hashtag feed. If you want to display a
							regular User feed then you can do this by selecting to connect a Personal account instead. For
							directions on how to convert your Personal profile into a Business profile please <a
								href="<?php echo esc_url( 'https://catchplugins.com/blog/instagram-business-profiles' ); ?>" target="_blank">see here</a>.</p>
					</span>

					<?php

			}

			?>

				<span class="modal-dismiss">X</span>
			</div><!-- .modal-page -->
		</div><!-- .modal-container -->

			<?php

}

?>

<div class="wrap">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'Social Gallery and Widget Pro', 'catch-instagram-feed-gallery-widget-pro' ); ?></h1>

	<?php if ( ! get_option( 'catch_instagram_feed_gallery_widget_dismiss' ) ) : ?>

					<div id="welcome-panel" class="welcome-panel">
						<a class="welcome-panel-close button dismiss" href="<?php echo esc_url( menu_page_url( 'catch-instagram-feed-gallery-widget-pro', false ) ); ?>"><?php esc_html_e( 'Dismiss', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>

						<div class="welcome-panel-content">
							<div class="welcome-panel-column-container">
								<div class="welcome-panel-column">
									<h3><img src="<?php echo esc_url( plugin_dir_url( __FILE__ ) . '../images/catch-instagram-feed-gallery-widget.svg' ); ?>" /><?php esc_html_e( 'Welcome to Social Gallery and Widget Pro Settings', 'catch-instagram-feed-gallery-widget-pro' ); ?></h3>

									<p><?php esc_html_e( 'Social Gallery and Widget Pro Plugin adds the posts from your Social account that you want to showcase on your website.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>

									<p><?php esc_html_e( 'You can add Social Gallery and Widget on your website. Simply either drag-and-drop the plugin in the widget area or you can add a shortcode from your WordPress dashboard if you want to place a copy of your Social feed directly onto your post/page.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</div>
							</div>
						</div>
					</div>

				<?php endif; // End if(). ?>

	<div class="catchp-content-wrapper">
		<div class="catchp_widget_settings">
			<form id="catch-instagram-feed-gallery-widget-main" method="post" action="options.php">
				<?php wp_nonce_field( CIFGWP_BASENAME, 'catch_gallery_nonce' ); // Use nonce for verification. ?>

				<h2 class="nav-tab-wrapper">
					<a class="nav-tab nav-tab-active" id="dashboard-tab" href="#dashboard"><?php esc_html_e( 'Dashboard', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>
					<a class="nav-tab" id="features-tab" href="#features"><?php esc_html_e( 'Features', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>
				</h2>

				<div id="dashboard" class="wpcatchtab  nosave active">

					<div id="public-usage" class="content-wrapper">
						<div class="header">
							<h3><?php esc_html_e( 'Add Social Feed as Gallery or Widget', 'catch-instagram-feed-gallery-widget-pro' ); ?></h3>

						</div><!-- .header -->
						<div class="content">
							<div class="as-widget">
								<p><strong><?php esc_html_e( '1. Add using Widget via our Social Gallery and Widget', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong></p>
								<p><a class="button" href="<?php echo esc_url( admin_url( 'widgets.php' ) ); ?>"><?php esc_html_e( 'Go to Widgets', 'catch-instagram-feed-gallery-widget-pro' ); ?></a></p>
							</div><!-- .as-widget -->
							<div class="as-shortcode">
								<p><strong><?php esc_html_e( '2. Add using Shortcode in Page/Post ', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong></p>
								<div class="shortcode-option-container">
									<div>
										<p><?php esc_html_e( 'Add in New:', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
										<a class="button" href="<?php echo esc_url( admin_url( 'post-new.php' ) ); ?>"><?php esc_html_e( 'Post' ); ?></a> / <a class="button" href="<?php echo esc_url( admin_url( 'post-new.php?post_type=page' ) ); ?>"><?php esc_html_e( 'Page' ); ?></a>
									</div>
									<div>
										<p><?php esc_html_e( 'Add in Existing:', 'catch-instagram-feed-gallery-widget-pro' ); ?></p><a class="button" href="<?php echo esc_url( admin_url( 'edit.php' ) ); ?>"><?php esc_html_e( 'Post' ); ?></a> / <a class="button" href="<?php echo esc_url( admin_url( 'edit.php?post_type=page' ) ); ?>"><?php esc_html_e( 'Page' ); ?></a>
									</div>
								</div><!-- .shortcode-option-container -->
							</div><!-- .as-shortcode -->
						</div><!-- .content -->
					</div><!-- #public-usage.content-wrapper -->


					<?php

					settings_fields( 'catch-instagram-feed-gallery-widget-group' );
					$options = catch_instagram_feed_gallery_widget_pro_get_options();

					if ( isset( $_GET['access_token'] ) ) {

						$access_token = sanitize_text_field( wp_unslash( $_GET['access_token'] ) );

					} elseif ( isset( $options['access_token'] ) && ( '' !== $options['access_token'] ) ) {

						$access_token = $options['access_token'];

					} else {

						$access_token = '';

					}

					?>

					<?php

					$options['access_token'] = $access_token;

					if ( isset( $_GET['access_token'] ) && '' !== $_GET['access_token'] ) {

						$re_data = Catch_Instagram_Feed_Gallery_Widget_Pro_Admin::update_data( $_GET['access_token'], $_GET['expires_in'] );

					}

					if ( isset( $options['username'] ) && ! empty( $options['username'] ) ) {

						$username = $options['username'];

					}

					// Reset all options
					if ( isset( $_GET['q'] ) && 'reset-all' === $_GET['q'] ) {

						if ( delete_option( 'catch_instagram_feed_gallery_widget_options' ) ) {

							$re_data['message'] = esc_html__( 'Options reset successfully.', 'catch-instagram-feed-gallery-widget-pro' );
							$re_data['type']    = 'notice-success';

						} else {

							$re_data['message'] = esc_html__( 'Reset failed, please try again', 'catch-instagram-feed-gallery-widget-pro' );
							$re_data['type']    = 'notice-error';

						}
					}

					// Reset Access Token
					if ( isset( $_GET['q'] ) && 'logout' === $_GET['q'] ) {

						$options                 = catch_instagram_feed_gallery_widget_pro_get_options();
						$options['user_id']      = '';
						$options['username']     = '';
						$options['access_token'] = '';

						if ( update_option( 'catch_instagram_feed_gallery_widget_options', $options ) ) {

							$re_data['message'] = esc_html__( 'Logged out successfully.', 'catch-instagram-feed-gallery-widget-pro' );
							$re_data['type']    = 'notice-success';

						} else {

							$re_data['message'] = esc_html__( 'Reset failed, please try again', 'catch-instagram-feed-gallery-widget-pro' );
							$re_data['type']    = 'notice-error';

						}
					}

					?>

					<div id="access-token" class="content-wrapper">
						<div class="header">
							<h2><?php esc_html_e( '+ Connect an Instagram Account', 'catch-instagram-feed-gallery-widget-pro' ); ?></h2>
						</div><!-- .header -->
						<div class="content">
							<p class="info wp-ui-highlight"><span class="dashicons dashicons-info"></span> <?php esc_html_e( 'You can show Social feed from any Private Social accounts by providing the Access Token. This section allows you to set API parameters.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>

							<?php

								$options       = get_option( 'catch_instagram_feed_gallery_widget_options' );
								$username      = isset( $options['username'] ) ? $options['username'] : '';
								$business_page = isset( $options['business_instagram_page'] ) ? $options['business_instagram_page'] : '';
								$user_id       = isset( $options['user_id'] ) ? $options['user_id'] : '';
								$access_token  = isset( $options['access_token'] ) ? $options['access_token'] : '';

							if ( $username && $access_token ) :

								?>

								<p><?php esc_html_e( 'You are logged in as', 'catch-instagram-feed-gallery-widget-pro' ); ?> <strong><?php echo esc_html( $username ); ?></strong></p>
								<p><?php esc_html_e( 'and your access token is', 'catch-instagram-feed-gallery-widget-pro' ); ?> <span class="button show-secure" data-hide="<?php esc_html_e( 'Hide', 'catch-instagram-feed-gallery-widget-pro' ); ?>" data-show="<?php esc_html_e( 'Show', 'catch-instagram-feed-gallery-widget-pro' ); ?>"><?php echo esc_html__( 'Show', 'catch-instagram-feed-gallery-widget-pro' ); ?></span></p>
								<p><strong class="dont-break-out secure"><?php echo esc_html( $access_token ); ?></strong></p>

							<?php endif; ?>

							<?php if ( '' === $username || '' === $access_token ) : ?>

								<?php $redirect_uri = 'https://catchplugins.com/social-gallery-widget-personal'; ?>

								<a class="button button-large get-token" href="https://api.instagram.com/oauth/authorize/?client_id=591128381467111
								&scope=user_profile,user_media
								&redirect_uri=<?php echo $redirect_uri; ?>?return_url=<?php echo esc_attr( $catch_instagram_feed_gallery_widget_page ); ?>
								&response_type=code
								&state=<?php echo esc_url( $catch_instagram_feed_gallery_widget_page ); ?>"><?php esc_html_e( '+ Connect an Instagram Account', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>

							<?php else : ?>

								<input type="hidden" name="catch-instagram-reset-nonce" id="catch-instagram-reset-nonce" value="<?php echo esc_attr( wp_create_nonce( 'catch-instagram-reset-nonce' ) ); ?>" />
								<a class="button button-large reset-token cifgw-instagram-logout" id="catch-instagram-feed-gallery-widget-reset" href="<?php echo esc_attr( $catch_instagram_feed_gallery_widget_page ) . '&q=logout'; ?>"><?php esc_html_e( 'Logout', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>

							<?php endif; ?>

							<?php if ( isset( $_GET['q'] ) || isset( $_GET['access_token'] ) ) : ?>

								<div class="notice <?php echo isset( $re_data['type'] ) ? esc_attr( $re_data['type'] ) : ''; ?>">
									<p><?php echo isset( $re_data['message'] ) ? esc_html( $re_data['message'] ) : ''; ?></p>
								</div>

							<?php endif; ?>

						</div><!-- .content -->
					</div><!-- #access-token.content-wrapper -->

					<div id="business-access-token" class="content-wrapper">
						<div class="header">
							<h2><?php esc_html_e( 'Get Access Token for Business Account (#HashTags)', 'catch-instagram-feed-gallery-widget-pro' ); ?></h2>
						</div><!-- .header -->
						<div class="content">

							<?php

								$business_access_token = isset( $options['business_access_token'] ) ? $options['business_access_token'] : '';
							if ( $business_access_token ) :

								?>
									<p><?php esc_html_e( 'You are logged in as', 'catch-instagram-feed-gallery-widget-pro' ); ?> <strong><?php echo esc_html( $business_page ); ?></strong></p>
									<p><?php esc_html_e( 'and your business access token is', 'catch-instagram-feed-gallery-widget-pro' ); ?> <span class="button show-secure" data-hide="<?php esc_html_e( 'Hide', 'catch-instagram-feed-gallery-widget-pro' ); ?>" data-show="<?php esc_html_e( 'Show', 'catch-instagram-feed-gallery-widget-pro' ); ?>"><?php esc_html_e( 'Show', 'catch-instagram-feed-gallery-widget-pro' ); ?></span></p>
									<p><strong class="dont-break-out secure"><?php echo esc_html( $business_access_token ); ?></strong></p>
									<input type="hidden" name="catch-instagram-fb-reset-nonce" id="catch-instagram-fb-reset-nonce" value="<?php echo esc_attr( wp_create_nonce( 'catch-instagram-fb-reset-nonce' ) ); ?>" />
									<a class="button button-large reset-token cifgw-fb-logout" id="catch-instagram-feed-gallery-widget-business-reset" href="<?php echo esc_attr( $catch_instagram_feed_gallery_widget_page ) . '&q=fb-logout'; ?>"><?php esc_html_e( 'Logout', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>

								<?php else : ?>

									<?php $redirect_uri = 'https://catchplugins.com/social-gallery-api/instagram-graph-api-redirect.php'; ?>
							<a class="button button-large get-token" href="https://www.facebook.com/dialog/oauth?client_id=449384635466766&redirect_uri=<?php echo $redirect_uri; ?>&scope=manage_pages,instagram_basic&state=<?php echo admin_url( 'admin.php?page=social-gallery-and-widget' ); ?>"><?php esc_html_e( '+ Connect an Instagram Account (Business)', 'catch-instagram-feed-gallery-widget-pro' ); ?></a>

							<?php endif; ?>

						</div><!-- .content -->
					</div><!-- #business-access-token.content-wrapper -->

					<div id="ctp-switch" class="content-wrapper col-3 catch-instagram-feed-gallery-widget-main">
						<div class="header">
							<h2><?php esc_html_e( 'Catch Themes & Catch Plugins Tabs', 'catch-instagram-feed-gallery-widget-pro' ); ?></h2>
						</div> <!-- .Header -->

						<div class="content">
							<p><?php echo esc_html__( 'If you want to turn off Catch Themes & Catch Plugins tabs option in Add Themes and Add Plugins page, please uncheck the following option.', 'catch-instagram-feed-gallery-widget-pro' ); ?>
							</p>
							<table>
								<tr>
									<td>

										<?php echo esc_html__( 'Turn On Catch Themes & Catch Plugin tabs', 'catch-instagram-feed-gallery-widget-pro' ); ?>

									</td>
									<td>

										<?php $ctp_options = ctp_get_options(); ?>

										<div class="module-header <?php echo $ctp_options['theme_plugin_tabs'] ? 'active' : 'inactive'; ?>">
											<div class="switch">
												<input type="hidden" name="catch_plugin_tabs_nonce" id="catch_plugin_tabs_nonce" value="<?php echo esc_attr( wp_create_nonce( 'catch_plugin_tabs_nonce' ) ); ?>" />
												<input type="checkbox" id="ctp_options[theme_plugin_tabs]" class="ctp-switch" rel="theme_plugin_tabs" <?php checked( true, $ctp_options['theme_plugin_tabs'] ); ?> >
												<label for="ctp_options[theme_plugin_tabs]"></label>
											</div>
											<div class="loader"></div>
										</div>
									</td>
								</tr>
							</table>

						</div>
					</div><!-- #ctp-switch -->
				</div><!-- .dashboard -->

				<div id="features" class="wpcatchtab save">
					<div class="content-wrapper col-3">
						<div class="header">
							<h3><?php esc_html_e( 'Features', 'catch-instagram-feed-gallery-widget-pro' ); ?></h3>

						</div><!-- .header -->
						<div class="content">
							<ul class="catchp-lists">
								<li>
									<strong><?php esc_html_e( 'Column Option', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Column Option allows you to choose from multiple column options. Several options are available for all column types in general to edit the default behavior.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Display by Tags', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'You can choose to showcase the content using the tags of any public account. The option is an alternative option to display the content if you don’t have the username ID of any specific public account.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Editable Load More', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'The Load More button is editable. It means you can always edit the text on “Load More” option. Add your own customized text on the Load More button and make your content more playful.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Grid Thumbnail', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Your Instagram feed’s thumbnails will be shown in a grid layout in this mode. Grids are known for keeping your content organized. In the same way here, the grid thumbnail will keep your Instagram feed well-organized and display them in a clean and effective way.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Image Sizes', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'You can choose the size of the images you want to display. You can either choose to display the thumbnail, small, or large size of the images.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Incredible Support', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'We have a great line of support team and support documentation. You do not need to worry about how to use the plugins we provide, just refer to our Tech Support Forum. Further, if you need to do advanced customization to your website, you can always hire our theme customizer!', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Layout Option', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Layout Option gives you the freedom to choose how you want to display your content. With multiple layout options, spice up the look of your website and make it more happening.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Lightbox', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Social Gallery and Widget Pro supports Lightbox by default. If you click on any of the image or video, then you will get the nice piece of Lightbox overlay. In this overlay window, you can watch the video, and navigate to other images on Instagram.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Likes and Comments Count', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Social Gallery and Widget Pro allows you to display the number of likes and comments on your Instagram feed. When you hover your mouse cursor over a specific Instagram post, it will show the number of likes and comments on the respective image.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Load More Option', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Load More—the name says it all. You have the option to display a button that will enable you to view the entire gallery on your website.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Masonry', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Social Gallery and Widget Pro allows you to showcase your Instagram feed in Masonry layout. It’s a type of grid layout that easily supports items of variable size. So, you don’t have to worry if your Instagram images’ sizes vary from one another, the masonry layout in our Social Gallery and Widget plugin will show your images in an elegant way, without showing the unnecessary gaps.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Multiple Instagram Feeds with no Limitations', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'You have the freedom to showcase multiple Instagram feeds and that too without any limitations. Displaying the multiple Instagram feeds have never been so convenient.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Number of Posts', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'You have the option to choose the number of posts you want to display on your website. Pick the number of posts that suits the best on your website.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Padding In-between Options', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'You have the freedom to place padding in-between your images. Enabling it will create a fine gap in-between your images and display them more neatly and elegantly.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Responsive Design', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'One of the key features of our plugins is that your website will magically respond and adapt to different screen sizes delivering an optimized design for iPhones, iPads, and other mobile devices. No longer will you need to zoom and scroll around when browsing on your mobile phone.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Round Thumbnail', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Round Thumbnail layout will showcase the thumbnails of your Instagram photos in a round format. With the round thumbnail enabled in Social Gallery and Widget Pro plugin, your Instagram feed’s thumbnails will be displayed in a very stylish and playful manner.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Shortcodes', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'With Shortcodes, you have the option to use the powerful shortcode options to style multiple contents in completely different ways.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Super Simple to Set Up', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'It is super easy to set up. Even the beginners can set it up easily and also, you do not need to have any coding knowledge. Just install, activate, customize it your way and enjoy the plugin.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>

								<li>
									<strong><?php esc_html_e( 'Widgets', 'catch-instagram-feed-gallery-widget-pro' ); ?></strong>
									<p><?php esc_html_e( 'Multitude of widget options provide you with the option to choose the widgets that you want to display. You can have full control over each widget’s visibility and appearance. You can assign different contents on your sidebars, footer and any sidebar widgets.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>
								</li>
							</ul>
						</div><!-- .content -->
					</div><!-- content-wrapper -->
				</div> <!-- Featured -->

			</form><!-- #catch-instagram-feed-gallery-widget-main -->

			<div id="request-queries" class="content-wrapper">
				<div class="content">

					<?php

					echo '<span class="dashicons dashicons-editor-help"></span>' .
					sprintf(
						wp_kses(
							'If you have any request queries, please visit <a href="%s" target="_blank">this link</a>.',
							array(
								'a' => array(
									'href'   => array(),
									'target' => array(),
								),
							)
						),
						esc_url( 'https://catchplugins.com/contact-us/' )
					);

					?>

				</div>
			</div> <!-- #request-queries -->

		</div><!-- .catchp_widget_settings -->

	</div> <!-- .catchp-content-wrapper -->

	<?php require_once plugin_dir_path( dirname( __FILE__ ) ) . '/partials/footer.php'; ?>

</div><!-- .wrap -->
