<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              catchplugins.com
 * @since             1.0.0
 * @package           Social_Gallery_and_Widget_Pro
 *
 * @wordpress-plugin
 * Plugin Name:       Social Gallery and Widget Pro
 * Plugin URI:        catchplugins.com/plugins/catch-instagram-feed-gallery-widget-pro
 * Description:       Social Gallery and Widget Pro Plugin is a simple solution to display your Instagram feed directly onto your website either using a widget or shortcode. You can also show your Instagram feeds in a post or page as well.
 * Version:           2.4.2
 * Author:            Catch Plugins
 * Author URI:        catchplugins.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       catch-instagram-feed-gallery-widget-pro
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {

	die;

}

if ( ! defined( 'CATCH_INSTGRAM_FEED_GALLERY_PRO_VERSION' ) ) {

	define( 'CATCH_INSTGRAM_FEED_GALLERY_PRO_VERSION', '2.4.2' );

}

// The URL of the directory that contains the plugin
if ( ! defined( 'CIFGWP_MAIN' ) ) {

	define( 'CIFGWP_MAIN', __FILE__ );

}

// The URL of the directory that contains the plugin
if ( ! defined( 'CIFGWP_URL' ) ) {

	define( 'CIFGWP_URL', plugin_dir_url( __FILE__ ) );

}


// The absolute path of the directory that contains the file
if ( ! defined( 'CIFGWP_PATH' ) ) {

	define( 'CIFGWP_PATH', plugin_dir_path( __FILE__ ) );

}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-catch-instagram-feed-gallery-widget-activator.php
 */
// Gets the path to a plugin file or directory, relative to the plugins directory, without the leading and trailing slashes.
if ( ! defined( 'CIFGWP_BASENAME' ) ) {

	define( 'CIFGWP_BASENAME', plugin_basename( __FILE__ ) );

}

function activate_catch_instagram_feed_gallery_widget_pro() {

	require_once plugin_dir_path( __FILE__ ) . 'includes/class-catch-instagram-feed-gallery-widget-pro-activator.php';
	Catch_Instagram_Feed_Gallery_Widget_Pro_Activator::activate();

}

register_activation_hook( __FILE__, 'activate_catch_instagram_feed_gallery_widget_pro' );

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-catch-instagram-feed-gallery-widget-deactivator.php
 */
function deactivate_catch_instagram_feed_gallery_widget_pro() {

	require_once plugin_dir_path( __FILE__ ) . 'includes/class-catch-instagram-feed-gallery-widget-pro-deactivator.php';
	Catch_Instagram_Feed_Gallery_Widget_Pro_Deactivator::deactivate();

}

register_deactivation_hook( __FILE__, 'deactivate_catch_instagram_feed_gallery_widget_pro' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-catch-instagram-feed-gallery-widget-pro.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_catch_instagram_feed_gallery_widget_pro() {

	$plugin = new Catch_Instagram_Feed_Gallery_Widget_Pro();
	$plugin->run();

}

run_catch_instagram_feed_gallery_widget_pro();


/**
 * Returns the options array for Top options
 *
 *  @since    1.0
 */
function catch_instagram_feed_gallery_widget_pro_get_options() {

	$defaults = catch_instagram_feed_gallery_widget_pro_default_options();
	$options  = get_option( 'catch_instagram_feed_gallery_widget_options', $defaults );

	return wp_parse_args( $options, $defaults );

}

/**
 * Return array of default options
 *
 * @since     1.0
 * @return    array    default options.
 */
function catch_instagram_feed_gallery_widget_pro_default_options( $option = null ) {

	$default_options = array(
		'username'                      => '',
		'user_id'                       => '',
		'access_token'                  => '',
		'expires_in'                    => 0,
		// Business Account #HashTags
		'tags'                          => '',
		'business_app_id'               => '',
		'business_app_secret'           => '',
		'business_instagram_page'       => '',
		'business_access_token'         => '',
		'business_expires_in'           => 0,
		'instagram_business_account_id' => '',
	);

	if ( null === $option ) {

		return apply_filters( 'catch_instagram_feed_gallery_widget_pro_options', $default_options );

	} else {

		return $default_options[ $option ];

	}
}

function catch_instagram_feed_gallery_widget_pro_sanitize_checkbox( $checked ) {

	// Boolean check.
	return ( ( isset( $checked ) && true === $checked ) ? true : false );

}

function catch_instagram_feed_gallery_widget_pro_sanitize_number_range( $number ) {

	// Number range check. Max is 30.
	$number = absint( $number );
	return ( isset( $number ) && $number <= 30 ) ? $number : 6;

}

/**
 * Returns an array of layouts registered for Catch Instagram Feed Gallery Widget.
 *
 * @since Catch Instagram Feed Gallery Widget 1.0
 */
function catch_instagram_feed_gallery_widget_pro_layout_option() {

	$options = array(
		'default' => esc_html__( 'Default', 'catch-instagram-feed-gallery-widget-pro' ),
		'masonry' => esc_html__( 'Masonry', 'catch-instagram-feed-gallery-widget-pro' ),
		'grid'    => esc_html__( 'Grid', 'catch-instagram-feed-gallery-widget-pro' ),
		'round'   => esc_html__( 'Round', 'catch-instagram-feed-gallery-widget-pro' ),
	);

	return apply_filters( 'catch_instagram_feed_gallery_widget_pro_layout_option', $options );

}

/**
 * Returns an array of columns registered for Catch Instagram Feed Gallery Widget.
 *
 * @since Catch Instagram Feed Gallery Widget 1.0
 */
function catch_instagram_feed_gallery_widget_pro_column_option() {

	$options = array(
		'two-columns'   => esc_html__( '2 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'three-columns' => esc_html__( '3 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'four-columns'  => esc_html__( '4 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'five-columns'  => esc_html__( '5 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'six-columns'   => esc_html__( '6 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'seven-columns' => esc_html__( '7 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
		'eight-columns' => esc_html__( '8 Columns', 'catch-instagram-feed-gallery-widget-pro' ),
	);

	return apply_filters( 'catch_instagram_feed_gallery_widget_pro_column_option', $options );

}

/**
 * Returns an array of account type registered for Catch Instagram Feed Gallery Widget.
 *
 * @since Catch Instagram Feed Gallery Widget 1.0
 */
function catch_instagram_feed_gallery_widget_pro_type() {

	$options = array(
		'users' => esc_html__( 'Username', 'catch-instagram-feed-gallery-widget-pro' ),
		'tags'  => esc_html__( 'Tags', 'catch-instagram-feed-gallery-widget-pro' ),
	);

	return apply_filters( 'catch_instagram_feed_gallery_widget_pro_type', $options );

}

/**
 * Returns an array of link type registered for Catch Instagram Feed Gallery Widget.
 *
 * @since Catch Instagram Feed Gallery Widget 1.0
 */
function catch_instagram_feed_gallery_widget_pro_link_option() {

	$options = array(
		'load_more' => esc_html__( 'Load More', 'catch-instagram-feed-gallery-widget-pro' ),
		'link_site' => esc_html__( 'View on Instagram', 'catch-instagram-feed-gallery-widget-pro' ),
		'none'      => esc_html__( 'Hide button', 'catch-instagram-feed-gallery-widget-pro' ),
	);

	return apply_filters( 'catch_instagram_feed_gallery_widget_pro_link_option', $options );

}

/** Add EDD Auto Updater */
require_once plugin_dir_path( __FILE__ ) . 'updater/updater.php';

function insta_pro_blocks_loader() {

	require_once plugin_dir_path( __FILE__ ) . 'includes/instagram-pro-block/index.php';

}

add_action( 'plugins_loaded', 'insta_pro_blocks_loader' );

/* CTP tabs removal options */
require plugin_dir_path( __FILE__ ) . '/includes/ctp-tabs-removal.php';

$ctp_options = ctp_get_options();

if ( 1 === $ctp_options['theme_plugin_tabs'] ) {

	/* Adds Catch Themes tab in Add theme page and Themes by Catch Themes in Customizer's change theme option. */
	if ( ! class_exists( 'CatchThemesThemePlugin' ) && ! function_exists( 'add_our_plugins_tab' ) ) {

		require plugin_dir_path( __FILE__ ) . '/admin/partials/CatchThemesThemePlugin.php';

	}
}
