<?php
/**
 * Adds Catch Instagram Feed Gallery Widget button to TinyMCE editor
 *
 * @link       catchplugins.com
 * @since      1.0.0
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 */

/**
 * The Catch Instagram Feed Gallery Widget button to TinyMCE editor
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 * @author     Catch Plugins <info@catchplugins.com>
 */
class Catch_Instagram_Feed_Gallery_Widget_Pro_Add_Editor_Button {

	/**
	 * Sets up thickbox and button
	 */
	public function __construct() {

		add_action( 'admin_footer', array( $this, 'thickbox_display' ) );
		add_action( 'media_buttons', array( $this, 'add_editor_button' ), 15 );

	}

	/**
	 * Add button to editor
	 */
	public function add_editor_button() {

		global $pagenow;

		$page_post_array = array( 'post-new.php', 'post.php' );

		// Only run in post/page creation and edit screens.
		if ( ! in_array( $pagenow, $page_post_array, true ) ) {

			return;

		}

		add_thickbox();
		echo '
	    <style>
	        #add-catch-instagram-feed-gallery-widget-shortcode:before {
	            vertical-align: middle;
	        }
	    </style>
	    <a href="#TB_inline?&inlineId=display-catch-instagram-feed-gallery-widget-shortcode&width=753&height=700" id="add-catch-instagram-feed-gallery-widget-shortcode" class="thickbox button" title="' .
		esc_attr__( 'Add Social Gallery and Widget Shortcodes', 'catch-instagram-feed-gallery-widget-pro' ) . '"><img src="' . esc_url( plugin_dir_url( __FILE__ ) . '../admin/images/catch-instagram-feed-gallery-widget.svg' ) . '" /></a>';

	}

	/**
	 * Adds Thickbox content to admin footer on page/post add and edit pages(includes CPT)
	 */
	public function thickbox_display() {

		$catch_instagram_feed_gallery_widget_options = catch_instagram_feed_gallery_widget_pro_get_options( 'catch_instagram_feed_gallery_widget_pro_options' );
		$username                                    = ( $catch_instagram_feed_gallery_widget_options['username'] ) ? $catch_instagram_feed_gallery_widget_options['username'] : '';

		?>

		<script type="text/javascript">
			jQuery(document).ready(function($){

				var prev_code;
				if( undefined !== $('div#wp-content-editor-container textarea').val() ) {

					prev_code = $('div#wp-content-editor-container textarea').val().match(/\[(catch-instagram-feed-gallery-widget.*)\]/);

				}

				if( undefined !== $('div#wp-content-editor-container textarea').val() ) {

					code = $('div#wp-content-editor-container textarea').val().match(/\[(catch-instagram-feed-gallery-widget.*)\]/);

					if( null !== code ) {

						$('#catch_instargarm_insert_shortcode').html('Update Shortcode');
						shortcode = '<' + code[1] + '>';

						$(shortcode).each(function() {

							$.each(this.attributes, function(){
								// this.attributes is not a plain object, but an array
								// of attribute nodes, which contain both the name and value
								// Getting previous values
								// Type Checkbox
								if ( 'padding' === this.name ){

									if( 'true' == this.value ){

										$("input[name='"+this.name+"'").attr('checked','checked');

									}

								}

								else if ( 'target' === this.name ){

									if( 'true' == this.value ){

										$("input[name='"+this.name+"'").attr('checked','checked');

									}

								}

								else if ( 'counts' === this.name ){

									if( 'true' == this.value ){

										$("input[name='"+this.name+"'").attr('checked','checked');

									}

								}

								else if ( 'lightbox' === this.name ){

									if( 'true' == this.value ){

										$("input[name='"+this.name+"'").attr('checked','checked');

									}

								}

								// Type Select
								else if ( 'type' === this.name ){

									$('#catch_instagram_feed_gallery_widget_shortcode_type option[value='+this.value+']').attr('selected','selected');

									if( 'tags' === this.value ) {

										$('#catch_instagram_feed_gallery_widget_shortcode_username').prev('label').html('Tag');

									}

								} else if ( 'layout' === this.name ) {

									$('#catch_instagram_feed_gallery_widget_shortcode_layout option[value='+this.value+']').attr('selected','selected');

								} else if ( 'column' === this.name ) {

									$('#catch_instagram_feed_gallery_widget_shortcode_column option[value='+this.value+']').attr('selected','selected');

								} else if ( 'link_type' === this.name ) {

									$('#catch_instagram_feed_gallery_widget_shortcode_link_type option[value='+this.value+']').attr('selected','selected');

								}

								// Type Text
								else {

									$("input[name='"+this.name+"'").val(this.value);

								}

							});

						});


						if( 'default' === $('.catch-instagram-feed-gallery-widget-layout').val() ) {

							$('#catch_instagram_feed_gallery_widget_shortcode_padding').val('');
							$('#catch_instagram_feed_gallery_widget_shortcode_padding').parent('p').hide();
							$('#catch_instagram_feed_gallery_widget_shortcode_column').parent('p').hide();

						}

						else {

							$('#catch_instagram_feed_gallery_widget_shortcode_column').parent('p').show();

						}

						// Trigger corresponsing input state on load
						$('#catch_instagram_feed_gallery_widget_shortcode_link_type').each(function(k, v){

							if( 'none' === $(v).val() ) {

								$(this).parent().parent().parent('#catch-instagram-feed-gallery-widget-shortcode-wrapper').find('#catch_instagram_feed_gallery_widget_shortcode_link_text').parents('p').slideUp();

							} else if( 'load_more' === $(this).val() ) {

								$(this).parent().parent().parent('#catch-instagram-feed-gallery-widget-shortcode-wrapper').find('#catch_instagram_feed_gallery_widget_shortcode_link_text').parents('p').slideDown();
								$(this).parent().parent().parent('#catch-instagram-feed-gallery-widget-shortcode-wrapper').find('#catch_instagram_feed_gallery_widget_shortcode_link_text').val('Load More');

							} else {

								$(this).parent().parent().parent('#catch-instagram-feed-gallery-widget-shortcode-wrapper').find('#catch_instagram_feed_gallery_widget_shortcode_link_text').parents('p').slideDown();
								$(this).parent().parent().parent('#catch-instagram-feed-gallery-widget-shortcode-wrapper').find('#catch_instagram_feed_gallery_widget_shortcode_link_text').val('View On Instagram');

							}

						});

					}

				}

				$('.catch_instargarm_inner').hide();
				$('#catch-instagram-feed-gallery-widget-shortcode-form').on('submit', function(e){

					if ( 'default' === $('.catch-instagram-feed-gallery-widget-layout').val() ){

						$('#catch_instagram_feed_gallery_widget_shortcode_column').val('');

					}

					e.preventDefault();
					var submit = true;
					var data = $(this).serializeArray();
					var shortcode = '';
					var insta_type = '';

					$.each(data, function(k, v){

						if( 'type' === v.name ) {

							insta_type = v.value;

						}
						if( 'username' === v.name ) {

							if( '' === v.value && 'tags' === insta_type ) {

								alert('Please enter tags');
								$('.catch-instagram-feed-gallery-widget-username').focus();
								submit = false;

							} else if( '' != v.value && 'tags' === insta_type ) {

								shortcode += v.name + '=' + '"' + v.value + '" ';

							}

						}else if( 'title' === v.name ) {

							if( '' ==! v.value ) {

								shortcode += v.name + '=' + '"' + v.value + '" ';

							}else {

								shortcode += v.name + '="" ';

							}

						}else if( 'checkbox' == v.type ) {

							shortcode += ' ' + v.name + '=' + '"' + v.checked + '"';

						}else {

							if( '' !== v.value ) {

								shortcode += ' ' + v.name + '=' + '"' + v.value + '" ';

							}

						}

					});

					if ( '' !== shortcode && submit ) {

						shortcode = '[catch-instagram-feed-gallery-widget ' + shortcode + ']';

						if( undefined !== $('div#wp-content-editor-container textarea').val() && undefined != prev_code ) {

							if(!tinyMCE.activeEditor)jQuery('.wp-editor-wrap .switch-tmce').trigger('click');

							var content = tinyMCE.activeEditor.getContent();

							var new_content = content.replace(prev_code[0], '');

							tinyMCE.activeEditor.setContent(new_content);

						}

						window.send_to_editor( shortcode );
						tb_remove();

					} else {

						return false;

					}

				});

			});

		</script>

		<div id="display-catch-instagram-feed-gallery-widget-shortcode" style="display: none;">
			<form id="catch-instagram-feed-gallery-widget-shortcode-form">
			<div id="catch-instagram-feed-gallery-widget-shortcode-wrapper" class="catch-instagram-feed-gallery-widget-shortcode-wrapper" style="margin: 0 auto; width: 500px;">

				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_title"><?php esc_html_e( 'Title', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<input type="text" id="catch_instagram_feed_gallery_widget_shortcode_title" name="title" class="widefat catch-instagram-feed-gallery-widget-title" value="Gallery and Widget for Instagram" />
				</p>

				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_type"><?php esc_html_e( 'Show Feed By', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<select id="catch_instagram_feed_gallery_widget_shortcode_type" name="type" class="widefat catch-instagram-feed-gallery-widget-type">

						<?php
						$account_type_choices = catch_instagram_feed_gallery_widget_pro_type();

						foreach ( $account_type_choices as $key => $value ) {

							echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, 'users', false ) . '>' . esc_attr( $value ) . '</option>';

						}

						?>

					</select>
				</p>

				<?php

					$display_none = 'display_none';

				?>

				<p style="display: none;">
					<label for="catch_instagram_feed_gallery_widget_shortcode_username"><?php esc_html_e( 'Tags', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<input rel="usersname" type="text" id="catch_instagram_feed_gallery_widget_shortcode_username" name="username" class="widefat catch-instagram-feed-gallery-widget-username" />
				</p>
				<p class="description" style="display: none;">

				<?php

					echo esc_html__( 'Separate multiple tags with comma', 'catch-instagram-feed-gallery-widget-pro' );

				?>

				</p>
				<span class="show-more button"><?php esc_html_e( 'More Options', 'catch-instagram-feed-gallery-widget-pro' ); ?><i class="dashicons dashicons-arrow-down"></i></span>
				<div class="more-options">
				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_layout"><?php esc_html_e( 'Layout', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<select id="catch_instagram_feed_gallery_widget_shortcode_layout" name="layout" class="widefat catch-instagram-feed-gallery-widget-layout">

						<?php

						$layout_type = catch_instagram_feed_gallery_widget_pro_layout_option();

						foreach ( $layout_type as $key => $value ) {

							echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, 'default', false ) . '>' . esc_attr( $value ) . '</option>';

						}

						?>

					</select>
				</p>

				<p>
					<input class="checkbox catch-instagram-feed-gallery-widget-padding" type="checkbox" id="catch_instagram_feed_gallery_widget_shortcode_padding" value="true" name="padding" />
					<label for="catch_instagram_feed_gallery_widget_shortcode_padding"><?php esc_html_e( 'Check to put padding on image', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
				</p>

				<p style="display: none;">
					<label for="catch_instagram_feed_gallery_widget_shortcode_column"><?php esc_html_e( 'Column', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<select id="catch_instagram_feed_gallery_widget_shortcode_column" name="column" class="widefat catch-instagram-feed-gallery-widget-column">

						<?php

						$column_choices = catch_instagram_feed_gallery_widget_pro_column_option();

						foreach ( $column_choices as $key => $value ) {

							echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, 'six-columns', false ) . '>' . esc_attr( $value ) . '</option>';

						}

						?>

					</select>
				</p>

				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_number"><?php esc_html_e( 'Number of items', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<input type="number" id="catch_instagram_feed_gallery_widget_shortcode_number" name="number" class="small-text catch-instagram-feed-gallery-widget-number" max="30" min="1" value="6" />
				</p>
				<p class="description"><?php esc_html_e( 'Max is 30.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>

				<p>
					<input class="checkbox catch-instagram-feed-gallery-widget-target" type="checkbox" id="catch_instagram_feed_gallery_widget_shortcode_target" value="true" name="target" />
					<label for="catch_instagram_feed_gallery_widget_shortcode_target"><?php esc_html_e( 'Turn on link to post on image', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
				</p>

				<p>
					<input class="checkbox catch-instagram-feed-gallery-widget-counts" type="checkbox" id="catch_instagram_feed_gallery_widget_shortcode_counts" value="true" name="counts" />
					<label for="catch_instagram_feed_gallery_widget_shortcode_counts"><?php esc_html_e( 'Show like and comment counts', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
				</p>

				<p>
					<input class="checkbox catch-instagram-feed-gallery-widget-lightbox" type="checkbox" id="catch_instagram_feed_gallery_widget_shortcode_lightbox" value="true" name="lightbox" />
					<label for="catch_instagram_feed_gallery_widget_shortcode_lightbox"><?php esc_html_e( 'Check to enable Lightbox', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
				</p>

				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_link_type"><?php esc_html_e( 'Link Type', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
					<select id="catch_instagram_feed_gallery_widget_shortcode_link_type" name="link_type" class="widefat catch-instagram-feed-gallery-widget-link-type">

						<?php

						$link_type_choices = catch_instagram_feed_gallery_widget_pro_link_option();

						foreach ( $link_type_choices as $key => $value ) {

							echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, 'load_more', false ) . '>' . esc_attr( $value ) . '</option>';

						}

						?>

					</select>
				</p>

				<p>
					<label for="catch_instagram_feed_gallery_widget_shortcode_link_text"><?php esc_html_e( 'Link Text', 'catch-instagram-feed-gallery-widget-pro' ); ?></label>:
					<input class="widefat catch-instagram-feed-gallery-widget-link-text" id="catch_instagram_feed_gallery_widget_shortcode_link_text" name="link_text" type="text" value="Load More" />
				</p>
				</div>
			</div>
			<p style="margin: 0 auto; width: 500px;">
				<button id="catch_instargarm_insert_shortcode" class="button button-primary button-large"><?php esc_html_e( 'Insert Shortcode', 'catch-instagram-feed-gallery-widget-pro' ); ?></button>
			</p>
			</form>
		</div>

		<?php

	}

}

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_add_catch_instagram_feed_gallery_widget_pro_editor_button_extension() {

	$catch_instagram_feed_gallery_widget_add_editor_button = new Catch_Instagram_Feed_Gallery_Widget_Pro_Add_Editor_Button;

}

run_add_catch_instagram_feed_gallery_widget_pro_editor_button_extension();
