<?php
/**
 * The Catch Instagram Feed Gallery Widget Helper of the plugin.
 *
 * @link       catchplugins.com
 * @since      1.0.0
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 */

/**
 * The Catch Instagram Feed Gallery Widget Helper of the plugin.
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 * @author     Catch Plugins <info@catchplugins.com>
 */
class Catch_Instagram_Feed_Gallery_Widget_Pro_Helper {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $url    The url to get feed from.
	 */
	private $url         = 'https://graph.instagram.com/';
	private $hashtag_url = 'https://graph.facebook.com/';

	/**
	 * Get Media and return in JSON format.
	 *
	 * @param string $type Account type.
	 *
	 * @param string $user Username.
	 *
	 * @param string $limit Count.
	 *
	 * @return json
	 */
	function get_media( $type, $user = null, $limit = null ) {

		if ( isset( $_POST['pagination_link'] ) ) {

			$url = $_POST['pagination_link'];

			if ( 'tags' === $type ) {

				$url = explode( ',', $_POST['pagination_link'] );

			}

			$json = self::get_remote_data_from_instagram_in_json( $url );
			$json = json_decode( $json, true );

			if ( 'tags' === $type ) {

				$json_array = array();

				foreach ( $url as $url ) {

					$json = self::get_remote_data_from_instagram_in_json( $url );
					$json = json_decode( $json, true );

					if ( isset( $json['data'] ) ) {

						$json_array[] = $json;
						$json         = $json_array;

					}
				}
			}

			return wp_json_encode( $json );

		} else {

			$options               = catch_instagram_feed_gallery_widget_pro_get_options();
			$username              = strtolower( $user ); // Sanitization.
			$token                 = $options['access_token'];
			$business_access_token = $options['business_access_token'];
			$business_id           = $options['instagram_business_account_id'];

			if ( 'tags' === $type ) {

				if ( '' === $business_access_token ) {

					$json = array(
						'code'  => '400',
						'error' => 'No access token',
					);

					return wp_json_encode( $json );

				}

				if ( '' === $business_id ) {

					$json = array(
						'code'  => '400',
						'error' => 'No Business Account ID Found',
					);

					return wp_json_encode( $json );

				}

				$tags       = explode( ',', $username );
				$tags       = array_unique( $tags );
				$json_array = array();
				$limit      = ceil( $limit / count( $tags ) );

				foreach ( $tags as $tag ) {

					if ( ! empty( $tag ) ) {

						$url = $this->hashtag_url . 'ig_hashtag_search?user_id=' . $business_id . '&access_token=' . $business_access_token . '&q=' . $tag;
						$tag = self::get_remote_data_from_instagram_in_json( $url );
						$tag = json_decode( $tag, true );

						if ( isset( $tag['error'] ) && '' !== $tag['error'] ) {

							$json = array(
								'code'  => '400',
								'error' => isset( $tag['error']['error_user_title'] ) ? $tag['error']['error_user_title'] : esc_html__( 'Could not find a matching hashtag', 'catch-instagram-feed-gallery-widget-pro' ),
							);

							return wp_json_encode( $json );

						}

						$tag_id = isset( $tag['data'][0]['id'] ) ? $tag['data'][0]['id'] : '';

						$url = $this->hashtag_url . $tag_id . '/recent_media?fields=id,media_type,comments_count,like_count,media_url,permalink,caption,children{media_url,id,media_type,thumbnail_url}&user_id=' . $business_id . '&access_token=' . $business_access_token . '&limit=' . absint( $limit );

						$json = self::get_remote_data_from_instagram_in_json( $url );
						$json = json_decode( $json, true );

						if ( isset( $json['data'] ) ) {

							$json_array[] = $json;
							$json         = $json_array;

						}
					}
				}

				return wp_json_encode( $json );

			} else {

				if ( '' === $token ) {

					$url = $this->hashtag_url . $business_id . '/media?fields=id,media_type,comments_count,like_count,media_url,thumbnail_url,permalink,caption,children{media_url,id,media_type,thumbnail_url}&access_token=' . $business_access_token . '&limit=' . absint( $limit );

				} else {

					$url = $this->url . 'me/media?fields=id,media_type,media_url,thumbnail_url,id,caption,username,comments,permalink,children{id,media_url,media_type,thumbnail_url}&access_token=' . esc_html( $token ) . '&limit=' . absint( $limit );

				}

				$json = self::get_remote_data_from_instagram_in_json( $url );
				return $json;
				$json = json_decode( $json, true );

			}
		} // End if().

	}

	/**
	 * Parse user media json
	 *
	 * @param string $url URL.
	 *
	 * @return json
	 */
	public function get_remote_data_from_instagram_in_json( $url ) {

		$content = wp_remote_get(
			$url,
			array(
				'timeout' => 100,
			)
		);

		if ( isset( $content->errors ) ) {

			$content = array(
				'meta' => array(
					'error_message' => $content->errors['http_request_failed']['0'],
				),
			);

			return $content;

		} else {

			if ( 'Invalid User' === $content['body'] ) {

				$json = array(
					'meta' => array(
						'error_message' => $content['body'],
					),
				);

			} else {

				$response = wp_remote_retrieve_body( $content );
				$json     = $response;

			}

			return $json;

		}

	}

	/**
	 * Convert json data to HTML
	 *
	 * @param  array $options Widget/Shortcode options.
	 */
	public function display( $options ) {

		$account_options = catch_instagram_feed_gallery_widget_pro_get_options();
		$output          = '';

		if ( isset( $options['username'] ) && '' === $options['username'] && '' === $account_options['instagram_business_account_id'] ) {

			$output .= esc_html__( 'Please connect an instagram account from the dashboard.', 'catch-instagram-feed-gallery-widget' );
			return $output;

		}

		$tags = trim( $options['username'] );
		$tags = str_replace( ',', '_', $tags );

		if ( false === ( $data = get_transient( 'catch_insta_pro_json_' . $options['type'] . '_' . $options['username'] . '_' . $options['number'] ) ) ) {

			// It wasn't there, so regenerate the data and save the transient.
			$data = $this->get_media( $options['type'], $options['username'], $options['number'] );
			$data = json_decode( $data, true );

			set_transient( 'catch_insta_pro_json_' . $options['type'] . '_' . $options['username'] . '_' . $options['number'], $data, HOUR_IN_SECONDS );

		}

		if ( ! $data ) {

			$output .= esc_html__( 'No Data', 'catch-instagram-feed-gallery-widget-pro' );
			return $output;

		} elseif ( isset( $data['meta']['error_message'] ) ) {

			if ( isset( $data['meta']['error_type'] ) ) {

				$output .= esc_html__( 'Provide API access token / Username', 'catch-instagram-feed-gallery-widget-pro' );
				return $output;

			} else {

				$output .= esc_html( $data['meta']['error_message'] );
				return $output;

			}
		} else {

			if ( ( isset( $options['title'] ) && ! empty( $options['title'] ) ) && ( isset( $options['element'] ) && 'shortcode' === $options['element'] ) ) {

				$output .= '<h2>' . esc_html( $options['title'] ) . '</h2>';

			}

			$catch_instagram_feed_gallery_widget_class = $options['layout'];
			if ( 'default' !== $options['layout'] ) {

				$catch_instagram_feed_gallery_widget_class .= ' ' . $options['column'];
				if ( true === $options['padding'] || 'true' === $options['padding'] ) {

					$catch_instagram_feed_gallery_widget_class .= ' with-padding';

				}
			}

			$output .= '<input type="hidden" name="catch-instagram-feed-gallery-widget-ajax-nonce" id="catch-instagram-feed-gallery-widget-ajax-nonce" value="' . esc_attr( wp_create_nonce( 'catch-instagram-feed-gallery-widget-ajax-nonce' ) ) . '" />';
			$output .= '<div class="catch-instagram-feed-gallery-widget-wrapper ' . esc_attr( $catch_instagram_feed_gallery_widget_class ) . '">';
			$output .= '<div class="catch-instagram-feed-gallery-widget-image-wrapper">';

			$args = array(
				'options' => $options,
				'data'    => $data,
			);

			if ( 'users' === $options['type'] ) {

				// Display by username selected.
				$result = self::user_display( $args );

			} else {

				// Display by tags selected.
				$result = self::tags_display( $args );

			} // End Else

			$result = json_decode( $result, true );

			$output .= $result['output'];
			$link    = $result['next_url'];

			$output .= '</div>';

			if ( 'load_more' === $options['link_type'] ) {

				if ( isset( $link ) && ! empty( $link ) ) { // Used esc_attr instead of esc_url.

					$output .= '<p class="instagram-button">
						<a class="load-more button cifgw"
						href="javascript:void(0);"
						data-pagination-link="' . esc_attr( $link ) . '"
						data-number="' . esc_attr( $options['number'] ) . '"
						data-type="' . esc_attr( $options['type'] ) . '"
						data-target="' . esc_attr( $options['target'] ) . '"
						data-layout="' . esc_attr( $options['layout'] ) . '"
						data-column="' . esc_attr( $options['column'] ) . '"
						data-username="' . esc_attr( $options['username'] ) . '"
						data-counts="' . esc_attr( $options['counts'] ) . '"
						data-lightbox="' . esc_attr( $options['lightbox'] ) . '">' . esc_html( $options['link_text'] ) . '</a><img class="loader" src="' . esc_url( plugin_dir_url( __FILE__ ) ) . '../public/images/loading.gif"/></p>';

				}
			} elseif ( 'link_site' === $options['link_type'] ) {

				$link    = '//instagram.com/' . $options['username'];
				$output .= '<p class="instagram-button"><a class="button" href="' . esc_url( $link ) . '" target="_blank"> ' . esc_html( $options['link_text'] ) . '</a></p>';

			}

			$output .= '</div>';

			// Return the HTML block.
			return $output;

		} // End if().

	}

	/**
	 * Convert json data to HTML for load more
	 */
	public function load_more() {

		if ( ! check_ajax_referer( 'catch-instagram-feed-gallery-widget-ajax-nonce', 'security', false ) ) {

			$response = array(
				'html' => 'Invalid Nonce',
				'link' => '',
			);

			echo wp_json_encode( $response );
			wp_die();

		}

		$html = '';
		$link = '';

		$data = $this->get_media( $_POST['type'] );
		$data = json_decode( $data, true );

		$args = array(
			'options' => $_POST,
			'data'    => $data,
		);

		if ( 'users' === $_POST['type'] ) {

			// Display by username selected.
			$result = self::user_display( $args );
			$result = json_decode( $result, true );
			$html  .= $result['output'];
			$link   = $result['next_url'];

		} else {

			// Display by username selected.
			$result = self::tags_display( $args );
			$result = json_decode( $result, true );
			$html  .= $result['output'];
			$link   = $result['next_url'];

		}

		$response = array(
			'html' => $html,
			'link' => $link,
		);

		echo wp_json_encode( $response );
		wp_die();

	}

	/**
	 * Text transform to sentence case
	 *
	 * @param string $string Layout of the widget.
	 */
	public function sentence_case( $string ) {

		$new_string = '';
		$sentences  = preg_split( '/([.?!]+)/', $string, -1, PREG_SPLIT_NO_EMPTY | PREG_SPLIT_DELIM_CAPTURE );

		foreach ( $sentences as $key => $sentence ) {

			$new_string .= ( $key & 1 ) === 0 ?
				ucfirst( strtolower( trim( $sentence ) ) ) :
				$sentence . ' ';

		}

		return trim( $new_string );

	}

	/**
	 * Display function for type user
	 *
	 * @param string $args options.
	 */
	public function user_display( $args ) {

		$output = '';

		if ( $_POST && defined( 'DOING_AJAX' ) && DOING_AJAX && ( check_ajax_referer( 'catch-instagram-feed-gallery-widget-ajax-nonce', 'security', false ) ) ) {

				$options = $_POST;

		} else {

			$options = $args['options'];

		}

		$data = isset( $args['data'] ) ? $args['data'] : '';

		if ( isset( $data['data'] ) && 0 === count( $data['data'] ) ) {

			$output .= esc_html__( 'No data / Invalid Username / Private Account', 'catch-instagram-feed-gallery-widget-pro' );
			return;

		}

		if ( ! $data ) {

			$output .= esc_html__( 'No Data', 'catch-instagram-feed-gallery-widget' );
			return $output;

		} elseif ( isset( $data['meta']['error_message'] ) ) {

			if ( isset( $data['meta']['error_type'] ) ) {

				$output .= esc_html__( 'Provide API access token / Username', 'catch-instagram-feed-gallery-widget' );
				return $output;

			} else {

				$output .= esc_html( $data['meta']['error_message'] );
				return $output;

			}
		} else {

			if ( ( isset( $options['title'] ) && ! empty( $options['title'] ) ) && ( isset( $options['element'] ) && 'shortcode' === $options['element'] ) ) {

				$output .= '<h2>' . esc_html( $options['title'] ) . '</h2>';

			}

			$key      = 'data';
			$next_url = isset( $data['paging']['next'] ) ? $data['paging']['next'] : '';

			if ( isset( $data[ $key ] ) && 0 === count( $data[ $key ] ) ) {

				$output .= esc_html__( 'No data / Invalid Username', 'catch-instagram-feed-gallery-widget' );
				return $output;

			}

			if ( isset( $data[ $key ] ) && 0 < count( $data[ $key ] ) ) {

				foreach ( $data['data'] as $src ) {

					$output .= '<li class="item">';
					$caption = isset( $src['caption'] ) ? $src['caption'] : '';

					if ( 'VIDEO' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || 'true' === $options['lightbox'] || '1' === $options['lightbox'] ) {

							$output .= '<a class="pretty lightbox" href="#' . absint( $src['id'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$output .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$output .= '<div id="' . absint( $src['id'] ) . '" style="display:none; position: absolute;">
									<video width="500" height="344" controls>
									<source src="' . esc_url( $src['media_url'] ) . '" type="video/mp4">
									Your browser does not support HTML5 video.
									</video>
								</div>';

						if ( isset( $src['thumbnail_url'] ) ) {

							$output .= '<img class="cifgw" src="' . esc_url( $src['thumbnail_url'] ) . '" />
									<span class="cifgw-overlay"></span>';

						}

						$output .= '<i class="overlay-icon dashicons dashicons-video-alt3"></i>';
						if ( true === $options['target'] || 'true' === $options['target'] || '1' === $options['target'] ) {

							$output .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$output .= '</a>';

					} elseif ( 'IMAGE' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || 'true' === $options['lightbox'] || '1' === $options['lightbox'] ) {
							$output .= '<a class="pretty lightbox" href="' . esc_url( $src['media_url'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$output .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$output .= '<img class="cifgw" src="' . esc_url( $src['media_url'] ) . '" />
									<span class="cifgw-overlay"></span>';

						if ( true === $options['target'] || 'true' === $options['target'] || '1' === $options['target'] ) {

							$output .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$output .= '</a>';

					} elseif ( 'CAROUSEL_ALBUM' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || 'true' === $options['lightbox'] || '1' === $options['lightbox'] ) {

							$output .= '<a class="pretty lightbox" href="#' . ( $src['id'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$output .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$output .= '<div id="' . ( $src['id'] ) . '" style="display:none; position: absolute;">';
						$output .= '<div id="gallery" class="owl-carousel owl-theme">';

						foreach ( $src['children']['data'] as $img ) {

							if ( 'IMAGE' === $img['media_type'] ) {

								$output .= '<div class="item"><img src="' . esc_url( $img['media_url'] ) . '" /></div>';

							} elseif ( 'VIDEO' === $img['type'] ) {

								$output .= '<div class="item"><video width="500" height="344" controls>
												<source src="' . esc_url( $img['media_url'] ) . '" type="video/mp4">
												Your browser does not support HTML5 video.
												</video></div>';

								if ( isset( $src['thumbnail_url'] ) ) {

									$output .= '<img class="cifgw" src="' . esc_url( $img['thumbnail_url'] ) . '" />';

								}
							}
						}

						$output .= '
								<img class="cifgw" src="' . esc_url( $src['media_url'] ) . '" />
								<span class="cifgw-overlay"></span>';

						$output .= '</div>';
						$output .= '</div>';

						$output .= '<i class="fa fa-clone overlay-icon"></i>';

						if ( true === $options['target'] || 'true' === $options['target'] || '1' === $options['target'] ) {

							$output .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$output .= '</a>';

					} // End if().

					$output .= '</li>';

				} // End foreach().
			}

			if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {

				$output = $output;

			} else {

				$output = '<ul>' . $output . '</ul>';

			}

			$result = array(

				'output'   => $output,
				'next_url' => $next_url,

			);

			return wp_json_encode( $result );

		}

	}

	/**
	 * Display function for type tag
	 *
	 * @param string $args options.
	 */
	public function tags_display( $args ) {

		if ( $_POST && defined( 'DOING_AJAX' ) && DOING_AJAX && ( check_ajax_referer( 'catch-instagram-feed-gallery-widget-ajax-nonce', 'security', false ) ) ) {

			$options = $_POST;

		} else {

			$options = $args['options'];

		}

		$arr1        = $args['data'];
		$output      = '';
		$inner       = '';
		$items_count = 1;

		if ( isset( $args['data']['error'] ) ) {

			$result = array(
				'output'   => $args['data']['error'],
				'next_url' => '',
			);

			return wp_json_encode( $result );

		}

		foreach ( $arr1 as $arr ) {

			$next_url[] = isset( $arr['paging']['next'] ) ? $arr['paging']['next'] : '';

			foreach ( $arr['data'] as $src ) {

				if ( $items_count <= $options['number'] ) {

					$inner  .= '<li class="item">';
					$caption = isset( $src['caption'] ) ? $src['caption'] : '';

					$like_comments_block = '<span class="cifgw-info">
									    	<span class="cifgw-count cifgw-likes">
									    		' . esc_attr( $src['like_count'] ) . '</span>
									    	<span class="cifgw-count cifgw-comments">
									    		' . esc_attr( $src['comments_count'] ) . '</span>
								    	</span>';

					if ( 'VIDEO' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || '1' === $options['lightbox'] || '1' === $options['lightbox'] ) {

							$inner .= '<a class="pretty lightbox" href="#' . ( $src['id'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$inner .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$source = isset( $src['media_url'] ) ? $src['media_url'] : '';
						$inner .= '<div id="' . ( $src['id'] ) . '" style="display:none; position: absolute;">
										<video width="500" height="344" controls>
										  <source src="' . esc_url( $source ) . '" type="video/mp4">
										  Your browser does not support HTML5 video.
										</video>
									</div>
									<video class="placeholder-video-image" src="' . esc_url( $source ) . '"></video>
									<span class="cifgw-overlay"></span>';

						if ( true === $options['counts'] || '1' === $options['counts'] || '1' === $options['counts'] ) {

							$inner .= $like_comments_block;

						}

						$inner .= '<i class="overlay-icon dashicons dashicons-video-alt3"></i>';
						if ( true === $options['target'] || '1' === $options['target'] || '1' === $options['target'] ) {

							$inner .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$inner .= '</a>';

					} elseif ( 'IMAGE' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || '1' === $options['lightbox'] || '1' === $options['lightbox'] ) {

							$inner .= '<a class="pretty lightbox" href="' . esc_url( $src['media_url'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$inner .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$inner .= '<img class="cifgw" src="' . esc_url( $src['media_url'] ) . '" />
										<span class="cifgw-overlay"></span>';

						if ( true === $options['counts'] || '1`' === $options['counts'] || '1' === $options['counts'] ) {

							$inner .= $like_comments_block;

						}

						if ( true === $options['target'] || '1' === $options['target'] || '1' === $options['target'] ) {

							$inner .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$inner .= '</a>';

					} elseif ( 'CAROUSEL_ALBUM' === $src['media_type'] ) {

						if ( true === $options['lightbox'] || '1' === $options['lightbox'] || '1' === $options['lightbox'] ) {

							$inner .= '<a class="pretty lightbox" href="#' . ( $src['id'] ) . '" rel="prettyPhoto[' . $options['username'] . ']" title="' . esc_attr( $caption ) . '">';

						} else {

							$inner .= '<a class="pretty" target="_blank" href="' . esc_url( $src['permalink'] ) . '">';

						}

						$inner .= '<div id="' . ( $src['id'] ) . '" style="display:none; position: absolute;">';
						$inner .= '<div id="gallery" class="owl-carousel owl-theme">';

						foreach ( $src['children']['data'] as $img ) {

							$source = isset( $img['media_url'] ) ? $img['media_url'] : '';

							if ( 'IMAGE' === $img['media_type'] ) {

								$inner .= '<div class="item"><img src="' . esc_url( $source ) . '" /></div>';

							} elseif ( 'VIDEO' === $img['media_type'] ) {

								$inner .= '<div class="item"><video width="500" height="344" controls>
												<source src="' . esc_url( $source ) . '" type="video/mp4">
												Your browser does not support HTML5 video.
											</video></div>';

							}
						}

							$inner .= '</div>';
							$inner .= '</div>';

							$src_id          = isset( $src['id'] ) ? $src['id'] : '';
							$media_url       = isset( $src['media_url'] ) ? esc_url( $src['media_url'] ) : '';
							$media_type      = $src['children']['data'][0]['media_type'];
							$child_media_url = isset( $src['children']['data'][0]['media_url'] ) ? esc_url( $src['children']['data'][0]['media_url'] ) : '';

						if ( 'IMAGE' === $media_type ) {

							$inner .= '
							    	<img class="cifgw" src="' . $child_media_url . '" />
									<span class="cifgw-overlay"></span>';

						} elseif ( 'VIDEO' === $media_type ) {

							$inner .= '<div id="' . ( $src_id ) . '" style="display:none; position: absolute;">
										<video width="500" height="344" controls>
										  <source src="' . esc_url( $child_media_url ) . '" type="video/mp4">
										  Your browser does not support HTML5 video.
										</video>
									</div>
								    	<img class="cifgw" src="' . $media_url . '" />
								    	<video class="placeholder-video-image"  src="' . esc_url( $child_media_url ) . '"></video>
										<span class="cifgw-overlay"></span>';

						}

						if ( true === $options['counts'] || '1`' === $options['counts'] || '1' === $options['counts'] ) {

							$inner .= $like_comments_block;

						}
							$inner .= '<i class="fa fa-clone overlay-icon"></i>';

						if ( true === $options['target'] || '1' === $options['target'] || '1' === $options['target'] ) {

							$inner .= '<a class="insta-link" href="' . esc_url( $src['permalink'] ) . '" target="_blank">Link</a>';

						}

						$inner .= '</a>';

					} // End if().

					$inner .= '</li>';

				} // End counter check if

				$items_count++;

			} // End foreach().
		} // End foreach

		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {

			$output .= $inner;

		} else {

			$output .= '<ul>' . $inner . '</ul>';

		}

		$link = implode( ',', $next_url );

		$result = array(
			'output'   => $output,
			'next_url' => $link,
		);

		return wp_json_encode( $result );

	}

}
