<?php
/**
 * The Catch Instagram Feed Gallery Widget for the plugin.
 *
 * @link       catchplugins.com
 * @since      1.0.0
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 */

/**
 * The Catch Instagram Feed Gallery Widget for the plugin.
 *
 * @package    Catch_Instagram_Feed_Gallery_Widget_Pro
 * @subpackage Catch_Instagram_Feed_Gallery_Widget_Pro/includes
 * @author     Catch Plugins <info@catchplugins.com>
 */
class Catch_Instagram_Feed_Gallery_Widget_Pro_Widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	/**
	 * Holds widget settings options, populated in constructor.
	 *
	 * @var array
	 */
	protected $options;

	/**
	 * Constructor. Set the default widget options and create widget.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		$this->defaults = array(
			'title'     => esc_html__( 'Social Gallery and Widget', 'catch-instagram-feed-gallery-widget-pro' ),
			'type'      => 'users',
			'username'  => '',
			'number'    => 6,
			'padding'   => 0,
			'layout'    => 'default',
			'column'    => 'six-columns',
			'target'    => 0,
			'counts'    => 0,
			'lightbox'  => 0,
			'link_type' => 'load_more',
			'link_text' => esc_html__( 'Load More', 'catch-instagram-feed-gallery-widget-pro' ),
		);

		$this->options = catch_instagram_feed_gallery_widget_pro_get_options( 'catch_instagram_feed_gallery_widget_pro_options' );

		$widget_ops = array(
			'classname'   => 'catch-instagram-feed-gallery-widget cifgw-pro',
			'description' => esc_html__( 'Displays your latest Instagram photos', 'catch-instagram-feed-gallery-widget-pro' ),
		);

		$control_ops = array(
			'id_base' => 'catch-instagram-feed-gallery-widget',
		);

		parent::__construct(
			'catch-instagram-feed-gallery-widget', // Base ID
			esc_html__( 'Social Gallery and Widget', 'catch-instagram-feed-gallery-widget-pro' ), // Name.
			$widget_ops,
			$control_ops
		);

	}

	/**
	 * Widget Form. Create widget form.
	 *
	 * @since 1.0.0
	 *
	 * @param array $instance Widget Instance.
	 */
	function form( $instance ) {

		$options = catch_instagram_feed_gallery_widget_pro_get_options( 'catch_instagram_feed_gallery_widget_options' );
		//$username = $options['username'];
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat catch-instagram-feed-gallery-widget-title" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>"><?php esc_html_e( 'Show Feed By', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'type' ) ); ?>" class="widefat catch-instagram-feed-gallery-widget-type">

				<?php

				$type_choices = catch_instagram_feed_gallery_widget_pro_type();

				foreach ( $type_choices as $key => $value ) {

					echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $instance['type'], false ) . '>' . esc_attr( $value ) . '</option>';

				}

				?>

			</select>
		</p>

		<?php $display_none = 'display_none'; ?>

		<p <?php echo ( 'tags' !== $instance['type'] ) ? ' style="display: none;"' : ''; ?>>
			<label for="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>"><?php echo esc_html__( 'Tags', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'username' ) ); ?>" value="<?php echo esc_attr( $instance['username'] ); ?>" class="widefat catch-instagram-feed-gallery-widget-username"
			<?php echo ( 'tags' === $instance['type'] ) ? ' required="required"' : ''; ?>
			/>
		</p>

		<p class="description" <?php echo ( 'tags' !== $instance['type'] ) ? ' style="display: none;"' : ''; ?>>

		<?php echo esc_html__( 'Separate multiple tags with comma', 'catch-instagram-feed-gallery-widget-pro' ); ?>

		</p>

		<span class="show-more button"><?php esc_html_e( 'More Options', 'catch-instagram-feed-gallery-widget-pro' ); ?><i class="dashicons dashicons-arrow-down"></i></span>
		<div class="more-options">
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>"><?php esc_html_e( 'Layout', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'layout' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'layout' ) ); ?>" class="widefat catch-instagram-feed-gallery-widget-layout">

					<?php

					$layout_type = catch_instagram_feed_gallery_widget_pro_layout_option();

					foreach ( $layout_type as $key => $value ) {

						echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $instance['layout'], false ) . '>' . esc_attr( $value ) . '</option>';

					}

					?>

				</select>
			</p>

			<p <?php echo ( 'default' === $instance['layout'] ) ? 'class="' . esc_attr( $display_none ) . '"' : ''; ?>>
				<input class="checkbox catch-instagram-feed-gallery-widget-padding" type="checkbox" <?php checked( $instance['padding'], true ); ?> id="<?php echo esc_attr( $this->get_field_id( 'padding' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'padding' ) ); ?>" />
				<label for="<?php echo esc_attr( $this->get_field_id( 'padding' ) ); ?>"><?php esc_html_e( 'Check to put padding on image', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
			</p>

			<p <?php echo ( 'default' === $instance['layout'] ) ? 'class="' . esc_attr( $display_none ) . '"' : ''; ?>>
				<label for="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>"><?php esc_html_e( 'Column', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'column' ) ); ?>" class="widefat catch-instagram-feed-gallery-widget-column">

					<?php

					$column_choices = catch_instagram_feed_gallery_widget_pro_column_option();

					foreach ( $column_choices as $key => $value ) {

						echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $instance['column'], false ) . '>' . esc_attr( $value ) . '</option>';

					}

					?>

				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of photos', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
				<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" value="<?php echo esc_attr( absint( $instance['number'] ) ); ?>" class="small-text catch-instagram-feed-gallery-widget-number" max="30" min="1" />
			</p>

			<p class="description"><?php esc_html_e( 'Max is 30.', 'catch-instagram-feed-gallery-widget-pro' ); ?></p>

			<p>
				<input class="checkbox catch-instagram-feed-gallery-widget-target" type="checkbox" <?php checked( $instance['target'], true ); ?> id="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'target' ) ); ?>" />
				<label for="<?php echo esc_attr( $this->get_field_id( 'target' ) ); ?>"><?php esc_html_e( 'Turn on link to post on image', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
			</p>

			<p <?php echo ( 'users' === $instance['type'] ) ? 'class="' . esc_attr( $display_none ) . '"' : ''; ?>>
				<input class="checkbox catch-instagram-feed-gallery-widget-counts" type="checkbox" <?php checked( $instance['counts'], true ); ?> id="<?php echo esc_attr( $this->get_field_id( 'counts' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'counts' ) ); ?>" />
				<label for="<?php echo esc_attr( $this->get_field_id( 'counts' ) ); ?>"><?php esc_html_e( 'Show like and comment counts', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
			</p>

			<p>
				<input class="checkbox catch-instagram-feed-gallery-widget-lightbox" type="checkbox" <?php checked( $instance['lightbox'], true ); ?> id="<?php echo esc_attr( $this->get_field_id( 'lightbox' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'lightbox' ) ); ?>" />
				<label for="<?php echo esc_attr( $this->get_field_id( 'lightbox' ) ); ?>"><?php esc_html_e( 'Check to enable Lightbox', 'catch-instagram-feed-gallery-widget-pro' ); ?></label><br />
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'link_type' ) ); ?>"><?php esc_html_e( 'Link Type', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'link_type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link_type' ) ); ?>" class="widefat catch-instagram-feed-gallery-widget-link-type">
					<?php

					$link_type_choices = catch_instagram_feed_gallery_widget_pro_link_option();

					foreach ( $link_type_choices as $key => $value ) {

						echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $instance['link_type'], false ) . '>' . esc_attr( $value ) . '</option>';

					}

					?>

				</select>
			</p>

			<p <?php echo ( 'none' === esc_attr( $instance['link_type'] ) ) ? 'class="' . esc_html( $display_none ) . '"' : ''; ?>>
				<label for="<?php echo esc_attr( $this->get_field_id( 'link_text' ) ); ?>"><?php esc_html_e( 'Link Text', 'catch-instagram-feed-gallery-widget-pro' ); ?>:</label>
				<input class="widefat catch-instagram-feed-gallery-widget-link-text" id="<?php echo esc_attr( $this->get_field_id( 'link_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link_text' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['link_text'] ); ?>" />
			</p>

		</div>

		<?php

	}

	/**
	 * Widget Update. Save/Update widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @param array $new_instance Widget New Instance.
	 * @param array $old_instance Widget Old Instance.
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		delete_transient( 'catch_insta_pro_json_' . $old_instance['type'] . '_' . $old_instance['username'] . '_' . $old_instance['number'] . '_' . $old_instance['layout'] . '_' . $old_instance['column'] . '_' . $old_instance['link_type'] . '_' . $old_instance['link_text'] );

		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['type']      = sanitize_key( $new_instance['type'] );
		$instance['username']  = sanitize_text_field( $new_instance['username'] );
		$instance['layout']    = sanitize_key( $new_instance['layout'] );
		$instance['padding']   = catch_instagram_feed_gallery_widget_pro_sanitize_checkbox( $new_instance['padding'] );
		$instance['column']    = sanitize_key( $new_instance['column'] );
		$instance['number']    = catch_instagram_feed_gallery_widget_pro_sanitize_number_range( $new_instance['number'] );
		$instance['target']    = catch_instagram_feed_gallery_widget_pro_sanitize_checkbox( $new_instance['target'] );
		$instance['counts']    = catch_instagram_feed_gallery_widget_pro_sanitize_checkbox( $new_instance['counts'] );
		$instance['lightbox']  = catch_instagram_feed_gallery_widget_pro_sanitize_checkbox( $new_instance['lightbox'] );
		$instance['link_type'] = sanitize_key( $new_instance['link_type'] );
		$instance['link_text'] = sanitize_text_field( $new_instance['link_text'] );

		return $instance;

	}

	/**
	 * Widget Form. Create widget form.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args Arguments.
	 * @param array $instance Instance.
	 */
	function widget( $args, $instance ) {

		// Merge with defaults.
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		echo $args['before_widget']; // WPCS: XSS ok, sanitization ok.

		// Set up the author bio.
		if ( ! empty( $instance['title'] ) ) {

			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title']; // WPCS: XSS ok, sanitization ok.

		}

		$instance['element'] = 'widget';

		$options  = catch_instagram_feed_gallery_widget_pro_get_options( 'catch_instagram_feed_gallery_widget_options' );
		$username = $options['username'];

		if ( ! $instance['username'] ) {

			$instance['username'] = $username;

		}

		$catch_instagram_feed_gallery_widget_helper = new Catch_Instagram_Feed_Gallery_Widget_Pro_Helper();
		echo $catch_instagram_feed_gallery_widget_helper->display( $instance ); // WPCS: XSS ok, sanitization ok.

		echo $args['after_widget']; // WPCS: XSS ok, sanitization ok.

	}

}

/**
 * Intiate Catch_Instagram_Feed_Gallery_Widget_Pro_Widget Class.
 *
 * @since 1.0.0
 */
function catch_instagram_feed_gallery_widget_pro_register_widget() {

	register_widget( 'Catch_Instagram_Feed_Gallery_Widget_Pro_Widget' );

}

add_action( 'widgets_init', 'catch_instagram_feed_gallery_widget_pro_register_widget' );
