(function($) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 */

	$(function() {
		$(window).resize(function() {
			resize();
		});

		pretty_photo_init();

		$(window).on('load scroll', function() {
			image_adjust();
			pretty_photo_init();
		});

		format_number();

		if (
			$('.catch-instagram-feed-gallery-widget-wrapper').hasClass(
				'masonry'
			)
		) {
			var $container = $('.masonry ul'),
				$hasMasonry = $container.data('masonry') ? true : false;
			if ($container.length > 0 && $hasMasonry) {
				// Destroy masonry if exists.
				$container.masonry('destroy');
			}
			$container.imagesLoaded(function() {
				$container.masonry({
					itemSelector: '.item'
				});
			});
		}

		$('.load-more').on('click', function(event) {
			var target = $(this);
			var next_link = target.attr('data-pagination-link');
			var size = target.attr('data-size');
			var number = target.attr('data-number');
			var type = target.attr('data-type');
			var target_link = target.attr('data-target');
			var layout = target.attr('data-layout');
			var username = target.attr('data-username');
			var counts = target.attr('data-counts');
			var lightbox = target.attr('data-lightbox');

			if (
				$(this)
					.attr('data-pagination-link')
					.indexOf('localhost') >= 0
			) {
				$(this).attr(
					'data-pagination-link',
					$(this)
						.attr('data-pagination-link')
						.replace('https://', 'http://')
				);
			}

			$.post(
				ajaxurl,
				{
					action: 'load_more',
					pagination_link: next_link,
					beforeSend: show_loader(target),
					size: size,
					number: number,
					type: type,
					username: username,
					target: target_link,
					counts: counts,
					lightbox: lightbox,
					security: $(
						'#catch-instagram-feed-gallery-widget-ajax-nonce'
					).val()
				},
				function(response) {
					if ('No data{"html":"","link":""}' == response) {
						hide_loader(target);
						target.remove();
						return false;
					} else {
						var result;
						if ((result = JSON.parse(response))) {
							if ('' !== result.html) {
								if ('masonry' === layout) {
									var $container = target
										.parent('p')
										.prev(
											'div.catch-instagram-feed-gallery-widget-image-wrapper'
										)
										.find('ul');
									var $items = $(result.html);

									$items.hide();
									// append to container
									$container.append($items);
									$items
										.imagesLoaded()
										.progress(function(imgLoad, image) {
											// get item
											// image is imagesLoaded class, not <img>
											// <img> is image.img
											var $item = $(image.img).parents(
												'.item'
											);
											// un-hide item
											$item.show();
											// masonry does its thing
											$container.masonry(
												'appended',
												$item
											);
										});
								} else {
									target
										.parent('p')
										.prev(
											'div.catch-instagram-feed-gallery-widget-image-wrapper'
										)
										.find('ul')
										.append(result.html);
								}
								hide_loader(target);
								image_adjust();
								pretty_photo_init();
								format_number();
							}
							if ('' !== result.link) {
								target.attr(
									'data-pagination-link',
									result.link
								);
							} else {
								target.remove();
							}
						}
					}
				}
			);

			function show_loader($target) {
				$target.hide();
				$target.next('.loader').show();
			}

			function hide_loader($target) {
				$target.next('.loader').hide();
				$target.show();
			}
		});
	});
	function image_adjust() {
		$('.catch-instagram-feed-gallery-widget-wrapper .item a.pretty').each(
			function() {
				var img = $(this).find('img.cifgw');
				var src = $(img).attr('src');
				$(img).css('display', 'none');
				if( undefined !== src ) {
					$(this).css('background-image', 'url(' + src + ')');
				}
				$(this).css('background-size', 'cover');
				$(this).css('background-position', 'center');
			}
		);
		resize();
	}

	function resize() {
		$('.catch-instagram-feed-gallery-widget-wrapper .item a.pretty').each(
			function() {
				var width = $(this)
					.parents('li')
					.width();
				var rect = $(this)
					.parents('li')[0]
					.getBoundingClientRect();
				if (rect.width) {
					width = rect.width;
				}
				$(this).css('height', width);
				$(this).css('width', width);
			}
		);
	}

	function pretty_photo_init() {
		$('.lightbox').prettyPhoto({
			theme: 'light_square',
			slideshow: false,
			height: 'auto',
			gallery_markup: '',
			social_tools: '',
			changepicturecallback: function() {
				// Initialize Owl Carousel on lightbox open and image change.
				carousel();
			} /* Called everytime an item is shown/changed */,
			callback: function() {
				// Destroy Owl Carousel on lightbox close.
				var owl = $('.owl-carousel');
				owl.trigger('destroy.owl.carousel').removeClass('owl-loaded');
				owl.find('.owl-stage-outer')
					.children()
					.unwrap();
			} /* Called when prettyPhoto is closed */
		});
	}

	function number_formater(num) {
		if (num > 999 && num < 100000) {
			num = (num / 1000).toFixed(1) + 'k';
		} else if (num > 100000) {
			num = (num / 100000).toFixed(1) + 'm';
		}
		return num;
	}

	function format_number() {
		$('.cifgw-count').each(function() {
			$(this).html(number_formater($(this).html()));
		});
	}

	function carousel() {
		$('.owl-carousel').owlCarousel({
			loop: false,
			margin: 10,
			nav: true,
			items: 1,
			dots: false,
			autoHeight: true
		});
		$('.pp_content_container .pp_details').css('float', 'none');
		$('.pp_content_container .pp_details').css('margin-bottom', 0);
		$('.pp_content').css('height', 'auto');
	}
})(jQuery);
