<?php

class CIFGWP_Plugin_Updater {

	protected $key           = null;
	protected $status        = null;
	protected $edd_store_url = null;
	protected $edd_item_name = null;
	protected $version       = null;
	protected $author        = null;
	protected $strings       = null;
	protected $file          = null;

	function __construct() {

		$this->file = CIFGWP_MAIN;

		if ( ! function_exists( 'get_plugin_data' ) ) {

			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

		}

		$plugin_data = get_plugin_data( $this->file );

		if ( empty( $plugin_data ) ) {

			return false;

		}

		//$plugin_data['Name'] = 'Catch Instagram Feed Gallery Widget Pro';

		$this->prefix        = str_replace( ' ', '_', strtolower( $plugin_data['Name'] ) );
		$this->slug          = str_replace( '-pro', '', str_replace( ' ', '-', strtolower( $plugin_data['Name'] ) ) );
		$this->key           = get_option( $this->prefix . '_license_key' );
		$this->status        = get_option( $this->prefix . '_license_status' );
		$this->edd_store_url = $plugin_data['AuthorURI'];
		$this->edd_item_name = $plugin_data['Name'];
		$this->version       = $plugin_data['Version'];
		$this->author        = $plugin_data['AuthorName'];
		$this->page_slug     = $this->slug . '-license';

		$this->strings = array(
			'plugin-license'            => esc_html__( 'Plugin License', 'catch-instagram-feed-gallery-widget-pro' ),
			'enter-key'                 => esc_html__( 'Enter your plugin license key.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-key'               => esc_html__( 'License Key', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-action'            => esc_html__( 'License Action', 'catch-instagram-feed-gallery-widget-pro' ),
			'deactivate-license'        => esc_html__( 'Deactivate License', 'catch-instagram-feed-gallery-widget-pro' ),
			'activate-license'          => esc_html__( 'Activate License', 'catch-instagram-feed-gallery-widget-pro' ),
			'status-unknown'            => esc_html__( 'License status is unknown.', 'catch-instagram-feed-gallery-widget-pro' ),
			'renew'                     => esc_html__( 'Renew?', 'catch-instagram-feed-gallery-widget-pro' ),
			'unlimited'                 => esc_html__( 'unlimited', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-key-is-active'     => esc_html__( 'License key is active.', 'catch-instagram-feed-gallery-widget-pro' ),
			'expires%s'                 => esc_html__( 'Expires on %s.', 'catch-instagram-feed-gallery-widget-pro' ),
			'expires-never'             => esc_html__( 'Lifetime License.', 'catch-instagram-feed-gallery-widget-pro' ),
			'%1$s/%2$-sites'            => esc_html__( 'You have %1$s / %2$s sites activated.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-key-expired-%s'    => esc_html__( 'License key expired %s.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-key-expired'       => esc_html__( 'License key has expired.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-keys-do-not-match' => esc_html__( 'License keys do not match.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-is-inactive'       => esc_html__( 'License is inactive.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-key-is-disabled'   => esc_html__( 'License key is disabled.', 'catch-instagram-feed-gallery-widget-pro' ),
			'site-is-inactive'          => esc_html__( 'Site is inactive.', 'catch-instagram-feed-gallery-widget-pro' ),
			'license-status-unknown'    => esc_html__( 'License status is unknown.', 'catch-instagram-feed-gallery-widget-pro' ),
			'update-notice'             => esc_html__( "Updating this theme will lose any customizations you have made. 'Cancel' to stop, 'OK' to update.", 'catch-instagram-feed-gallery-widget-pro' ),
			'update-available'          => esc_html__( '<strong>%1$s %2$s</strong> is available. <a href="%3$s" class="thickbox" title="%4s">Check out what\'s new</a> or <a href="%5$s"%6$s>update now</a>.', 'catch-instagram-feed-gallery-widget-pro' ),
		);

		add_action( 'admin_menu', array( $this, 'add_menu' ) );
		add_action( 'admin_notices', array( $this, 'admin_notices' ) );
		add_action( 'admin_init', array( $this, 'plugin_updater' ) );
		add_action( 'admin_init', array( $this, 'register_option' ) );
		add_action( 'admin_init', array( $this, 'activate_license' ) );
		add_action( 'admin_init', array( $this, 'deactivate_license' ) );

	}

	// This function enables EDD's one click plugin udpater if license is valid and active
	function plugin_updater() {

		// Check if license is valid and active
		if ( 'valid' === $this->status ) {

			if ( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {

				// load our custom updater
				include dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php';

			}

			// setup the updater
			$edd_updater = new EDD_SL_Plugin_Updater(
				$this->edd_store_url,
				$this->file,
				array(
					'version'   => $this->version, // current version number
					'license'   => $this->key,    // license key (used get_option above to retrieve from DB)
					'item_name' => $this->edd_item_name, // name of this plugin
					'author'    => $this->author,  // author of this plugin
				)
			);
		}

	}

	// Add license page as plugin's submenu
	function add_menu() {

		add_submenu_page(
			$this->slug, // $parent_slug.
			esc_html__( 'Manage License', 'catch-instagram-feed-gallery-widget-pro' ), // $page_title.
			esc_html__( 'Manage License', 'catch-instagram-feed-gallery-widget-pro' ), // $menu_title.
			'manage_options', // $capability.
			$this->page_slug, // $menu_slug.
			array( $this, 'license_page' ) // callback function.
		);

	}


	/************************************
	 * the code below is just a standard
	 * options page. Substitute with
	 * your own.
	 *************************************/

	function license_page() {

		// Checks license status to display under license key
		if ( ! $this->key ) {

			$message = esc_html__( 'Enter your plugin license key.', 'catch-instagram-feed-gallery-widget-pro' );

		} else {

			// delete_transient( $this->prefix . '_license_message' );
			if ( ! get_transient( $this->prefix . '_license_message', false ) ) {

				set_transient( $this->prefix . '_license_message', $this->status_message( $this->check_license() ), ( 60 * 60 * 24 ) ); // Set transient for a day.

			}

			$message = get_transient( $this->prefix . '_license_message' );

		}

		?>

		<div class="wrap">
			<h2><?php esc_html_e( 'Plugin License Options', 'catch-instagram-feed-gallery-widget-pro' ); ?></h2>
			<form method="post" action="options.php">

			<?php settings_fields( $this->prefix . '_license' ); ?>

				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row" valign="top">
							<?php esc_html_e( 'License Key', 'catch-instagram-feed-gallery-widget-pro' ); ?>
							</th>
							<td>
								<input id="<?php echo esc_html( $this->prefix ); ?>_license_key" name="<?php echo esc_html( $this->prefix ); ?>_license_key" type="text" class="regular-text" value="<?php echo esc_attr( $this->key ); ?>" />
								<p class="description"><?php echo esc_html( $message ); ?></p>
							</td>
						</tr>

					<?php if ( false !== $this->key && '' !== $this->key ) { ?>

							<tr valign="top">
								<th scope="row" valign="top">
									<?php esc_html_e( 'License Action', 'catch-instagram-feed-gallery-widget-pro' ); ?>
								</th>
								<td>
									<?php if ( false !== $this->status && 'valid' === $this->status ) { ?>
										<?php wp_nonce_field( $this->prefix . '_nonce', $this->prefix . '_nonce' ); ?>
										<input type="submit" class="button-secondary" name="edd_license_deactivate" value="<?php esc_html_e( 'Deactivate License', 'catch-instagram-feed-gallery-widget-pro' ); ?>"/>
										<?php
									} else {
										wp_nonce_field( $this->prefix . '_nonce', $this->prefix . '_nonce' );
										?>
										<input type="submit" class="button-secondary" name="edd_license_activate" value="<?php esc_html_e( 'Activate License', 'catch-instagram-feed-gallery-widget-pro' ); ?>"/>
									<?php } ?>
								</td>
							</tr>

						<?php } ?>

					</tbody>
				</table>

					<?php submit_button(); ?>

			</form>
		</div>
			<?php
	}

	function register_option() {

		// creates our settings in the options table
		register_setting( $this->prefix . '_license', $this->prefix . '_license_key', array( $this, 'sanitize_license' ) );

	}

	function sanitize_license( $new ) {

		$old = get_option( $this->prefix . '_license_key' );

		if ( $old && $old !== $new ) {

			delete_option( $this->prefix . '_license_status' ); // new license has been entered, so must reactivate
			delete_transient( $this->prefix . '_license_message' ); // new license has been entered, so delete license message transient

		}

		return $new;

	}

	/************************************
	 * this illustrates how to activate
	 * a license key
	 *************************************/

	function activate_license() {

		// listen for our activate button to be clicked
		if ( isset( $_POST['edd_license_activate'] ) && isset( $_POST[ $this->prefix . '_nonce' ] ) ) {

			// run a quick security check
			if ( ! check_admin_referer( $this->prefix . '_nonce', $this->prefix . '_nonce' ) ) {

				return; // get out if we didn't click the Activate button

			}

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'activate_license',
				'license'    => $this->key,
				'item_name'  => urlencode( $this->edd_item_name ), // the name of our product in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response = wp_remote_post(
				$this->edd_store_url,
				array(
					'timeout'   => 15,
					'sslverify' => false,
					'body'      => $api_params,
				)
			);

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

				$message = ( is_wp_error( $response ) && ! empty( $response->get_error_message() ) ) ? $response->get_error_message() : __( 'An error occurred, please try again.' );

			} else {

				$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			}

			if ( isset( $license_data->success ) && false === $license_data->success ) {

				switch ( $license_data->error ) {

					case 'expired':
						$message = sprintf(
							esc_html__( 'Your license key expired on %s.' ),
							date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
						);
						break;

					case 'revoked':
						$message = esc_html__( 'Your license key has been disabled.' );
						break;

					case 'missing':
						$message = esc_html__( 'Invalid license.' );
						break;

					case 'invalid':
					case 'site_inactive':
						$message = esc_html__( 'Your license is not active for this URL.' );
						break;

					case 'item_name_mismatch':
						$message = sprintf( esc_html__( 'This appears to be an invalid license key for %s.' ), $this->edd_item_name );
						break;

					case 'no_activations_left':
						$message = esc_html__( 'Your license key has reached its activation limit.' );
						break;

					default:
						$message = esc_html__( 'An error occurred, please try again.' );
						break;

				}
			}

			// Check if anything passed on a message constituting a failure
			if ( ! empty( $message ) ) {

				$base_url = admin_url( 'admin.php?page=' . $this->page_slug );
				$redirect = add_query_arg(
					array(
						'sl_activation' => 'false',
						'message'       => urlencode( $message ),
					),
					$base_url
				);

				wp_redirect( $redirect );
				exit();

			}

			update_option( $this->prefix . '_license_status', $license_data->license );

			// delete license message transient on activation
			delete_transient( $this->prefix . '_license_message' );

			$message  = esc_html__( 'Your license has been activated successfully.', 'catch-instagram-feed-gallery-widget-pro' );
			$base_url = admin_url( 'admin.php?page=' . $this->page_slug );
			$redirect = add_query_arg(
				array(
					'sl_activation' => 'true',
					'message'       => urlencode( $message ),
				),
				$base_url
			);

			wp_redirect( $redirect );
			exit;
		}
	}

	/***********************************************
	 * Illustrates how to deactivate a license key.
	 * This will decrease the site count
	 ***********************************************/

	function deactivate_license() {

		// listen for our activate button to be clicked
		if ( isset( $_POST['edd_license_deactivate'] ) && isset( $_POST[ $this->prefix . '_nonce' ] ) ) {

			// run a quick security check
			if ( ! check_admin_referer( $this->prefix . '_nonce', $this->prefix . '_nonce' ) ) {

				return; // get out if we didn't click the Activate button

			}

			$license_data = $this->check_license();

			if ( isset( $license_data->license ) && 'valid' !== $license_data->license ) {
				delete_option( $this->prefix . '_license_status' );

				// delete license message transient on deactivation
				delete_transient( $this->prefix . '_license_message' );
				return false;
			}

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'deactivate_license',
				'license'    => $this->key,
				'item_name'  => urlencode( $this->edd_item_name ), // the name of our product in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response = wp_remote_post(
				$this->edd_store_url,
				array(
					'timeout'   => 15,
					'sslverify' => false,
					'body'      => $api_params,
				)
			);

			// make sure the response came back okay
			if ( is_wp_error( $response ) ) {

				$message = ( is_wp_error( $response ) && ! empty( $response->get_error_message() ) ) ? $response->get_error_message() : __( 'An error occurred, please try again.' );

			} else {

				$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			}

			if ( isset( $license_data->success ) && false === $license_data->success ) {

				$message = esc_html__( 'Something went wrong, please try again.', 'catch-instagram-feed-gallery-widget-pro' );

			}

			// Check if anything passed on a message constituting a failure
			if ( ! empty( $message ) ) {

				$base_url = admin_url( 'admin.php?page=' . $this->page_slug );
				$redirect = add_query_arg(
					array(
						'sl_activation' => 'false',
						'message'       => urlencode( $message ),
					),
					$base_url
				);

				wp_redirect( $redirect );
				exit();

			}

			delete_option( $this->prefix . '_license_status' );

			// delete license message transient on deactivation
			delete_transient( $this->prefix . '_license_message' );

			$message  = esc_html__( 'Your license has been deactivated successfully.', 'catch-instagram-feed-gallery-widget-pro' );
			$base_url = admin_url( 'admin.php?page=' . $this->page_slug );
			$redirect = add_query_arg(
				array(
					'sl_activation' => 'true',
					'message'       => urlencode( $message ),
				),
				$base_url
			);

			wp_redirect( $redirect );
			exit();

		}

	}

	/************************************
	 * this illustrates how to check if
	 * a license key is still valid
	 * the updater does this for you,
	 * so this is only needed if you
	 * want to do something custom
	 *************************************/

	function check_license() {
		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => $this->key,
			'item_name'  => urlencode( $this->edd_item_name ),
			'url'        => home_url(),
		);

		// Call the custom API.
		$response = wp_remote_post(
			$this->edd_store_url,
			array(
				'timeout'   => 15,
				'sslverify' => false,
				'body'      => $api_params,
			)
		);

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {

				$message = $response->get_error_message();

			} else {

				$message = $this->strings['license-status-unknown'];

			}

			return $message;

		} else {

			$license_data = json_decode( wp_remote_retrieve_body( $response ) );
			return $license_data;
		}
	}

	function status_message( $license_data ) {

		// If response doesn't include license data, return
		if ( ! is_object( $license_data ) ) {

			return $license_data;

		}
		if ( ! isset( $license_data->license ) ) {

			$message = $this->strings['license-status-unknown'];
			return $message;

		}

		// We need to update the license status at the same time the message is updated
		if ( $license_data && isset( $license_data->license ) ) {

			update_option( $this->prefix . '_license_status', $license_data->license );
			delete_transient( $this->prefix . '_license_message' );

		}

		// Get expire date
		$expires = false;
		if ( isset( $license_data->expires ) && 'lifetime' !== $license_data->expires ) {

			$expires = date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) );
			// $renew_link = '<a href="' . esc_url( $this->get_renewal_link() ) . '" target="_blank">' . $this->strings['renew'] . '</a>';

		} elseif ( isset( $license_data->expires ) && 'lifetime' === $license_data->expires ) {

			$expires = 'lifetime';

		}

		// Get site counts
		$site_count    = isset( $license_data->site_count ) ? $license_data->site_count : '';
		$license_limit = isset( $license_data->license_limit ) ? $license_data->license_limit : '';

		// If unlimited
		if ( 0 === $license_limit ) {

			$license_limit = $this->strings['unlimited'];

		}

		if ( 'valid' === $license_data->license ) {

			$message = $this->strings['license-key-is-active'] . ' ';
			if ( isset( $expires ) && 'lifetime' != $expires ) {

				$message .= sprintf( $this->strings['expires%s'], $expires ) . ' ';

			}

			if ( isset( $expires ) && 'lifetime' === $expires ) {

				$message .= $this->strings['expires-never'];

			}
			if ( $site_count && $license_limit ) {

				$message .= sprintf( $this->strings['%1$s/%2$-sites'], $site_count, $license_limit );

			}
		} elseif ( 'expired' === $license_data->license ) {

			if ( $expires ) {

				$message = sprintf( $this->strings['license-key-expired-%s'], $expires );

			} else {

				$message = $this->strings['license-key-expired'];

			}

			if ( $renew_link ) {

				$message .= ' ' . $renew_link;

			}
		} elseif ( 'invalid' === $license_data->license ) {

			$message = $this->strings['license-keys-do-not-match'];

		} elseif ( 'inactive' === $license_data->license ) {

			$message = $this->strings['license-is-inactive'];
			delete_option( $this->prefix . '_license_status' );
			delete_transient( $this->prefix . '_license_message' );

		} elseif ( 'disabled' === $license_data->license ) {

			$message = $this->strings['license-key-is-disabled'];

		} elseif ( 'site_inactive' === $license_data->license ) {

			// Site is inactive
			$message = $this->strings['site-is-inactive'];

		} else {

			$message = $this->strings['license-status-unknown'];

		}

		return $message;
	}

	/**
	 * This is a means of catching errors from the activation method above and displaying it to the customer
	 */
	function admin_notices() {

		if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) && isset( $_GET['page'] ) && ( $this->page_slug === $_GET['page'] ) ) {

			switch ( $_GET['sl_activation'] ) {

				case 'false':
					$message = urldecode( $_GET['message'] );

					?>

				<div class="error">
					<p><?php echo $message; ?></p>
				</div>

					<?php

					break;

				case 'true':
					$message = urldecode( $_GET['message'] );

					?>

				<div class="updated">
					<p><?php echo esc_html( $message ); ?></p>
				</div>

					<?php

					break;
				default:
					// Developers can put a custom success message here for when activation is successful if they way.
					break;

			}
		}

	}

}

if ( is_admin() ) {
	new CIFGWP_Plugin_Updater();
}
